/**********************************************************************/
/* Switches between US and BR 274 keyboards                           */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/* The latest version of this program can be found at                 */
/*               www.degeus.com/rexx                                  */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/* This program is released under the terms of the GNU license, see   */
/*               www.gnu.org/copyleft/gpl.html                        */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/* (c) 1999-2001 Marcus C. de Geus                                    */
/*               marcus@degeus.com                                    */
/*               www.degeus.com                                       */
/*                                                                    */
/**********************************************************************/
/*                                                                    */
/* Use it if you like it. Don't if you don't. No legalese.            */
/*                                                                    */
/**********************************************************************/

signal on Halt                                                                   /* handle halt condition */

if (\LoadRexxUtils()) then                                                                       /* if we cannot use or load the Rexx utility functions */
do
 call Halt                                                                                       /* just quit */
end

parse source . . ProgSpec                                                        /* get ProgSpec */
SourceDir = filespec('D',ProgSpec)||filespec('P',ProgSpec)                       /* the source directory name */

QueueName = rxqueue('CREATE')                                                    /* get a queue name */
call rxqueue 'SET',QueueName                                                     /* prepare the queue */

'keyb | rxqueue '||QueueName                                                     /* call KEYB and send the output to the queue */

parse pull  . . . Keyboard                                                       /* get the data we want */
call rxqueue 'DELETE',QueueName                                                  /* get rid of the queue */

if (Keyboard = 'BR.') then                                                       /* if we have a BR keyboard */
do
 'keyb US'                                                                       /* switch to the US keyboard */
 call syssetobjectdata '<KEYB_US_BR274>','ICONFILE='||SourceDir||'keybisus.ico'  /* and change the icon */
end
else                                                                             /* if we've got a US keyboard */
do
 'keyb BR 274'                                                                   /* switch to the Brazilian keyboard */
 call syssetobjectdata '<KEYB_US_BR274>','ICONFILE='||SourceDir||'keybisbr.ico'  /* and change the icon */
end

call Halt                                                                        /* quit */

/**********************************************************************/
LoadRexxUtils: procedure                                                                         /* loads REXX utility functions if necessary */
/**********************************************************************/

Success = 1                                                                                      /* all is well to start with */

if (rxfuncquery('SysLoadFuncs') >< 0) then                                                       /* if we have to load the REXX utility functions */
do
 if (rxfuncadd('SysLoadFuncs','RexxUtil','SysLoadFuncs') = 0) then                               /* if we can register the general loading function */
 do
  call sysloadfuncs                                                                              /* call the general loading function */
  say 'Rexx utility functions loaded'                                                            /* report */
 end
 else                                                                                            /* if we cannot register the general loading function */
 do
  say  'Cannot load Rexx utility functions'                                                      /* report */
  Success = 0                                                                                    /* no success */
 end
end

return Success                                                                                   /* end of LoadRexxUtils */

/**********************************************************************/
Halt:                                                                            /* handle halt condition */
/**********************************************************************/

exit                                                                             /* that's all, folks! */
